@@ -1,6 +1,6 @@
 /* ncdu - NCurses Disk Usage
 
-  Copyright (c) 2007-2021 Yoran Heling
+  Copyright (c) 2007-2022 Yoran Heling
 
   Permission is hereby granted, free of charge, to any person obtaining
   a copy of this software and associated documentation files (the
@@ -162,21 +162,26 @@ static char *dir_read(int *err) {
   }
 
   buf = xmalloc(buflen);
-  errno = 0;
 
-  while((item = readdir(dir)) != NULL) {
+  while(1) {
+    size_t len, req;
+    errno = 0;
+    if ((item = readdir(dir)) == NULL) {
+      if(errno)
+        *err = 1;
+      break;
+    }
     if(item->d_name[0] == '.' && (item->d_name[1] == 0 || (item->d_name[1] == '.' && item->d_name[2] == 0)))
       continue;
-    size_t req = off+3+strlen(item->d_name);
+    len = strlen(item->d_name);
+    req = off+3+len;
     if(req > buflen) {
       buflen = req < buflen*2 ? buflen*2 : req;
       buf = xrealloc(buf, buflen);
     }
     strcpy(buf+off, item->d_name);
-    off += strlen(item->d_name)+1;
+    off += len+1;
   }
-  if(errno)
-    *err = 1;
   if(closedir(dir) < 0)
     *err = 1;
 
