@@ -95,8 +95,10 @@ struct dir_ext {
 
 /* program state */
 extern int pstate;
-/* read-only flag, 1+ = disable deletion, 2+ = also disable shell */
-extern int read_only;
+/* enabled features */
+extern int can_delete;
+extern int can_shell;
+extern int can_refresh;
 /* minimum screen update interval when calculating, in ms */
 extern long update_delay;
 /* filter directories with CACHEDIR.TAG */
@@ -109,6 +111,16 @@ extern int extended_info;
 extern int follow_symlinks;
 /* flag whether we want to follow firmlinks */
 extern int follow_firmlinks;
+/* display SI units */
+extern int si;
+/* show apparent sizes */
+extern int show_as;
+/* graph display setting */
+extern int graph;
+/* column visibility */
+extern int show_items;
+extern int show_mtime;
+
 
 /* handle input from keyboard and update display */
 int input_handle(int);
