@@ -37,10 +37,18 @@
 int uic_theme;
 int winrows, wincols;
 int subwinr, subwinc;
-int si;
 static char thou_sep;
 
 
+void die(const char *fmt, ...) {
+  va_list arg;
+  va_start(arg, fmt);
+  vfprintf(stderr, fmt, arg);
+  va_end(arg);
+  exit(1);
+}
+
+
 char *cropstr(const char *from, int s) {
   static char dat[4096];
   int i, j, o = strlen(from);
@@ -146,7 +154,7 @@ char *fmtmode(unsigned short mode) {
 }
 
 
-void read_locale() {
+void read_locale(void) {
 #ifdef HAVE_LOCALE_H
   char *locale_thou_sep;
 #endif
@@ -267,7 +275,7 @@ static const struct {
   {0,0,0}
 };
 
-void uic_init() {
+void uic_init(void) {
   size_t i, j;
 
   start_color();
@@ -441,3 +449,9 @@ void addparentstats(struct dir *d, int64_t size, int64_t asize, uint64_t mtime,
 void *xmalloc(size_t size) { wrap_oom(malloc(size)) }
 void *xcalloc(size_t n, size_t size) { wrap_oom(calloc(n, size)) }
 void *xrealloc(void *mem, size_t size) { wrap_oom(realloc(mem, size)) }
+
+char *xstrdup(const char *str) {
+  char *r = xmalloc(strlen(str)+1);
+  strcpy(r, str);
+  return r;
+}
