@@ -30,6 +30,9 @@
 #include <ncurses.h>
 
 
+void die(const char *, ...);
+
+
 /* UI colors: (foreground, background, attrs)
  *  NAME         OFF         DARK                DARK-BG   */
 #define UI_COLORS \
@@ -185,5 +188,7 @@ void *xmalloc(size_t);
 void *xcalloc(size_t, size_t);
 void *xrealloc(void *, size_t);
 
+char *xstrdup(const char *);
+
 #endif
 
